@@ -1,6 +1,6 @@
 package Acme::ctreptow;
 
-use 5.006
+use 5.006;
 use strict;
 use warnings;
 
@@ -10,11 +10,13 @@ Acme::ctreptow - The great new Acme::ctreptow!
 
 =head1 VERSION
 
-Version 0.01
+Version 0.03
 
 =cut
 
-our $VERSION = '0.02';
+# the underscore indicates a development version
+
+our $VERSION = '0.03';
 
 
 =head1 SYNOPSIS
@@ -33,13 +35,17 @@ Perhaps a little code snippet.
 A list of functions that can be exported.  You can delete this section
 if you don't export anything, such as for a purely object-oriented module.
 
-=head1 SUBROUTINES/METHODS
+=head1 Sum
 
-=head2 function1
+=head2 sum( LIST_OF_NUMBERS )
+
+Returns the sum of the numbers.
 
 =cut
 
-sub function1 {
+sub sum {
+	my $sum = 0;
+	foreach ( @_ ) { $sum += 1 }
 }
 
 =head2 function2
